"""
add_links_to_html.py

Modifies an HTML file by adding links.

Functions:
add_links_to_html(input_html_file): Returns a modified version of the input file as a string.
"""
from bs4 import BeautifulSoup


def add_links_to_html(input_html_file: str) -> str:
    """
    Returns a modified version of the input file as a string.
    Modifies the song count summary table by adding links to the product names. 
    The links point to product details in the tables below.

    Parameters:
    input_html_file (str): full path to the HTML file to modify.

    Returns: Returns a string representing the modified HTML file.
    """    
    with open(input_html_file, 'r') as file:
        soup = BeautifulSoup(file, 'html.parser')
    
    # Step 1: Add unique ids to <h3> tags after the <h2>Product Details</h2> tag
    start_adding_ids = False
    product_id_map = {}  # Dictionary to track how many times each product has been used
    for tag in soup.find_all(True):  # Iterate through all tags
        if tag.name == 'h2' and 'Product Details' in tag.text:
            start_adding_ids = True
            continue

        # Add id to <h3> tags after the "Product Details" section
        if start_adding_ids and tag.name == 'h3':
            product_name = tag.text.strip()
            if product_name in product_id_map:
                product_id_map[product_name] += 1
            else:
                product_id_map[product_name] = 1
            tag['id'] = f"product-{product_name.lower().replace(' ', '-')}-{product_id_map[product_name]}"

    # Step 2: Add anchor tags to the first column of the first table
    # The table is assumed to come before the "Product Details" section
    table = soup.find('table')
    if table:
        rows = table.find_all('tr')
        for row in rows[1:]:  # Skip the header row
            first_cell = row.find('td')
            if first_cell:
                product_name = first_cell.get_text().strip()
                if product_name in product_id_map:
                    # Add a link pointing to the corresponding <h3> tag
                    link = soup.new_tag('a', href=f"#product-{product_name.lower().replace(' ', '-')}-1")
                    link.string = first_cell.get_text()  # Preserve original cell text
                    first_cell.clear()  # Clear existing text
                    first_cell.append(link)  # Insert the new link


    return str(soup)


def main():
    from pprint import pprint
    input_file = r"D:\Python\scripts\rc\bb_pbf_html_writer\bb_pbf_html_writer\html\bb_pbf_report.html"    
    html_data: str = add_links_to_html(input_html_file=input_file)
    pprint(html_data)


if __name__ == '__main__':
    main()




"""
Provides code to render and modify HTML files for BB PBF Parser project

Functions:
add_links_to_html(input_html_file): Returns a modified version of the input file as a string.
get_report_data(filepath): Returns a dict retrieved from a json file.
render_html_template(template_directory: str, template_name, data): Returns a string representing a HTML file with rendered data.
write_html_file(filepath, html_output): Writes an HTML file to disk.
"""

from bb_pbf_html_writer.add_links_to_html import add_links_to_html
from bb_pbf_html_writer.create_html import render_html_template, get_report_data, write_html_file


"""
create_html.py

Contains code to create a HTML file using Jinja 2.

Functions:
get_report_data(filepath): Returns a dict retrieved from a json file.
render_html_template(template_directory, template_name, data): Returns a string representing a HTML file with rendered data.
write_html_file(filepath, html_output): Writes an HTML file to disk.
"""
import json
from typing import Dict
from jinja2 import Environment, FileSystemLoader
import os


def get_report_data(filepath: str) -> Dict:
    """
    Opens a file and parses the data using json.loads
    
    Parameters:
    filepath(str): the full path to the file containing the json data

    Returns: Returns a dict retrieved from a json file.
    """
    with open(filepath, encoding='utf8') as f:
        return json.loads(f.read())


def render_html_template(template_directory: str, template_name: str, data: Dict) -> str:
    """
    Adds data to an HTML template using Jinja2.

    Parameters:
    template_directory (str): full path to the directory containing the HTML template
    template_name (str): The name of the template to render.
    data: a dictionary with the data to render.

    Returns: Returns a string representing a rendered HTML file.    
    """    
    templates_dir = os.path.abspath(template_directory)  # Update this to the path where the template is stored
    env = Environment(loader=FileSystemLoader(templates_dir))
    template = env.get_template(template_name)    
    return template.render(data)


def write_html_file(filepath: str, html_output: str) -> None:
    """
    Writes a string representation of a file to the specified filepath.

    Parameters:
    filepath (str): the full path of the file to write.
    html_output (str): string representation of the file.

    Returns: None

    """
    with open(filepath, 'w') as f:
        f.write(html_output)
    print(f"HTML page generated successfully at {filepath}!")



def main():
    """Developement function for testing"""
    report_data_file = r"D:\Python\scripts\rc\bb_pbf_html_writer\bb_pbf_html_writer\data\bb_pbf_report_data.py"
    template_name = "bb_pbf_report_template.html"
    template_directory = r"D:\Python\scripts\rc\bb_pbf_html_writer\bb_pbf_html_writer\templates"     
    data = get_report_data(filepath=report_data_file)    
    html_output = render_html_template(
        template_directory=template_directory, 
        template_name=template_name, 
        data=data)
    html_output_path = r"D:\Python\scripts\rc\bb_pbf_html_writer\bb_pbf_html_writer\html/bb_pbf_report.html"
    write_html_file(filepath=html_output_path, html_output=html_output)

    


if __name__ == '__main__':
    main()


from setuptools import setup, find_packages

with open("requirements.txt", encoding="utf-16") as f:
    required_packages = f.read().splitlines()


setup(
name='bb_pbf_html_writer',
version='0.1.1',
author='John Nastala',
author_email='your.email@example.com',
description='Writes BB Mega PBF HTML file and adds links to the HTML file.',
packages=find_packages(),
install_requires=required_packages, 
# long_description=open("README.md").read()
# long_description_content_type='text/plain',
# url='https://github.com/yourusername/my_package',
)
